Description Usage Format Source
This dataset contains coronavirus data of 3 different types from 8 states in Australia.
1 |
a tibble with 2120 observations and 8 variables:
Country: full country name
State: one of Australian Capital Territory, New South Wales, Northern Territory, Queensland, South Australia, Tasmania, Victoria, Western Australia
date: date from 2020-01-12 to 2020-10-02
confirmed: the cumulative number of the confirmed cases
recovered: the cumulative number of the recovered cases
deaths: the cumulative number of the death cases
daily_confirmed: the daily number of the confirmed cases
daily_recovered: the daily number of the recovered cases
daily_deaths: the daily number of the death cases
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.