dateselection: Create a date range input

Description Usage Arguments Value

View source: R/uifunction.R

Description

Create a date range input

Usage

1
dateselection(starttime, endtime)

Arguments

starttime

the beginning of the date

endtime

the end of the date

Value

It shows a date range input in shiny app and related interactive plots and table.

If the input in user interface does not satisfy the condition,the shiny app will not display the plots and table.


etc5523-2020/r-package-assessment-yliu0320 documentation built on Jan. 1, 2021, 1:13 a.m.