Description Usage Arguments Value
Create a date range input
1 | dateselection(starttime, endtime)
|
starttime |
the beginning of the date |
endtime |
the end of the date |
It shows a date range input in shiny app and related interactive plots and table.
If the input in user interface does not satisfy the condition,the shiny app will not display the plots and table.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.